@@ -4,19 +4,15 @@ import tensorflow as tf
 import tensorflow.keras.backend as K
 
 from tensorflow.keras.models import Model
-from tensorflow.keras.layers import (Input, Dropout, BatchNormalization, Add,
+from tensorflow.keras.layers import (Input, BatchNormalization, Add,
                                      LeakyReLU, Concatenate, Lambda, Dense,
-                                     Reshape, Permute, Multiply,
-                                     Conv2D, Conv2DTranspose,
-                                     MaxPooling2D, GlobalAveragePooling2D,
-                                     UpSampling2D,
-                                     Conv3D, Conv3DTranspose,
-                                     MaxPooling3D, GlobalAveragePooling3D,
-                                     UpSampling3D)
+                                     Reshape, Multiply, Conv2D,
+                                     MaxPooling2D, GlobalAveragePooling2D, Conv3D,
+                                     MaxPooling3D, GlobalAveragePooling3D)
 
 def create_resnet_model_2d(input_image_size,
                            input_scalars_size=0,
-                           number_of_classification_labels=1000,
+                           number_of_outputs=1000,
                            layers=(1, 2, 3, 4),
                            residual_block_schedule=(3, 4, 6, 3),
                            lowest_resolution=64,
@@ -48,8 +44,8 @@ def create_resnet_model_2d(input_image_size,
         Optional integer specifying the size of the input vector for scalars that
         get concatenated to the fully connected layer at the end of the network.
 
-    number_of_classification_labels : integer
-        Number of classification labels.
+    number_of_outputs : integer
+        Number of units in final layer.
 
     layers : tuple
         A tuple determining the number of 'filters' defined at for each layer.
@@ -61,14 +57,14 @@ def create_resnet_model_2d(input_image_size,
         Number of filters at the initial layer.
 
     cardinality : integer
-        perform ResNet (cardinality = 1) or ResNeX (cardinality does not 1 but,
+        perform ResNet (cardinality = 1) or ResNeX (cardinality is not 1 but,
         instead, powers of 2---try '32').
 
     squeeze_and_excite : boolean
         add the squeeze-and-excite block variant.
 
     mode : string
-        'classification' or 'regression'.  Default = 'classification'.
+        'classification', 'sigmoid' or 'regression'.  Default = 'classification'.
 
     Returns
     -------
@@ -100,7 +96,7 @@ def create_resnet_model_2d(input_image_size,
         if number_of_filters % cardinality != 0:
             raise ValueError('number_of_filters `%` cardinality != 0')
 
-        number_of_group_filters = int(number_of_filters / cardinality)
+        number_of_group_filters = number_of_filters // cardinality
 
         convolution_layers = []
         for j in range(cardinality):
@@ -136,11 +132,11 @@ def create_resnet_model_2d(input_image_size,
         return(x)
 
     def residual_block_2d(model,
-                         number_of_filters_in,
-                         number_of_filters_out,
-                         strides=(1, 1),
-                         project_shortcut=False,
-                         squeeze_and_excite=False):
+                          number_of_filters_in,
+                          number_of_filters_out,
+                          strides=(1, 1),
+                          project_shortcut=False,
+                          squeeze_and_excite=False):
         shortcut = model
 
         model = Conv2D(filters=number_of_filters_in,
@@ -161,14 +157,14 @@ def create_resnet_model_2d(input_image_size,
                        padding='same')(model)
         model = BatchNormalization()(model)
 
-        if project_shortcut == True or strides != (1,1):
+        if project_shortcut or strides != (1,1):
             shortcut = Conv2D(filters=number_of_filters_out,
                               kernel_size=(1, 1),
                               strides=strides,
                               padding='same')(shortcut)
             shortcut = BatchNormalization()(shortcut)
 
-        if squeeze_and_excite == True:
+        if squeeze_and_excite:
             model = squeeze_and_excite_block_2d(model)
 
         model = Add()([shortcut, model])
@@ -217,6 +213,8 @@ def create_resnet_model_2d(input_image_size,
         layer_activation = 'softmax'
     elif mode == 'regression':
         layer_activation = 'linear'
+    elif mode == 'sigmoid':
+        layer_activation = 'sigmoid'
     else:
         raise ValueError('mode must be either `classification` or `regression`.')
 
@@ -224,11 +222,11 @@ def create_resnet_model_2d(input_image_size,
     if input_scalars_size > 0:
         input_scalars = Input( shape = (input_scalars_size,) )
         concatenated_layer = Concatenate()([outputs, input_scalars])
-        outputs = Dense(units=number_of_classification_labels,
+        outputs = Dense(units=number_of_outputs,
                         activation=layer_activation)(concatenated_layer)
         resnet_model = Model(inputs=[input_image, input_scalars], outputs = outputs)
     else:
-        outputs = Dense(units=number_of_classification_labels,
+        outputs = Dense(units=number_of_outputs,
                         activation=layer_activation)(outputs)
         resnet_model = Model(inputs=input_image, outputs=outputs)
 
@@ -236,7 +234,7 @@ def create_resnet_model_2d(input_image_size,
 
 def create_resnet_model_3d(input_image_size,
                            input_scalars_size=0,
-                           number_of_classification_labels=1000,
+                           number_of_outputs=1000,
                            layers=(1, 2, 3, 4),
                            residual_block_schedule=(3, 4, 6, 3),
                            lowest_resolution=64,
@@ -268,8 +266,8 @@ def create_resnet_model_3d(input_image_size,
         Optional integer specifying the size of the input vector for scalars that
         get concatenated to the fully connected layer at the end of the network.
 
-    number_of_classification_labels : integer
-        Number of classification labels.
+    number_of_outputs : integer
+        Number of units in final layer.
 
     layers : tuple
         A tuple determining the number of 'filters' defined at for each layer.
@@ -281,14 +279,14 @@ def create_resnet_model_3d(input_image_size,
         Number of filters at the initial layer.
 
     cardinality : integer
-        perform ResNet (cardinality = 1) or ResNeX (cardinality does not 1 but,
+        perform ResNet (cardinality = 1) or ResNeX (cardinality is not 1 but,
         instead, powers of 2---try '32').
 
     squeeze_and_excite : boolean
         add the squeeze-and-excite block variant.
 
     mode : string
-        'classification' or 'regression'.  Default = 'classification'.
+        'classification', 'sigmoid' or 'regression'.  Default = 'classification'.
 
     Returns
     -------
@@ -320,7 +318,7 @@ def create_resnet_model_3d(input_image_size,
         if number_of_filters % cardinality != 0:
             raise ValueError('number_of_filters `%` cardinality != 0')
 
-        number_of_group_filters = int(number_of_filters / cardinality)
+        number_of_group_filters = number_of_filters // cardinality
 
         convolution_layers = []
         for j in range(cardinality):
@@ -381,14 +379,14 @@ def create_resnet_model_3d(input_image_size,
                        padding='same')(model)
         model = BatchNormalization()(model)
 
-        if project_shortcut == True or strides != (1,1,1):
+        if project_shortcut or strides != (1,1,1):
             shortcut = Conv3D(filters=number_of_filters_out,
                               kernel_size=(1, 1, 1),
                               strides=strides,
                               padding='same')(shortcut)
             shortcut = BatchNormalization()(shortcut)
 
-        if squeeze_and_excite == True:
+        if squeeze_and_excite:
             model = squeeze_and_excite_block_3d(model)
 
         model = Add()([shortcut, model])
@@ -438,6 +436,8 @@ def create_resnet_model_3d(input_image_size,
         layer_activation = 'softmax'
     elif mode == 'regression':
         layer_activation = 'linear'
+    elif mode == 'sigmoid':
+        layer_activation = 'sigmoid'
     else:
         raise ValueError('mode must be either `classification` or `regression`.')
 
@@ -445,11 +445,11 @@ def create_resnet_model_3d(input_image_size,
     if input_scalars_size > 0:
         input_scalars = Input( shape = (input_scalars_size,) )
         concatenated_layer = Concatenate()([outputs, input_scalars])
-        outputs = Dense(units=number_of_classification_labels,
+        outputs = Dense(units=number_of_outputs,
                         activation=layer_activation)(concatenated_layer)
         resnet_model = Model(inputs=[input_image, input_scalars], outputs = outputs)
     else:
-        outputs = Dense(units=number_of_classification_labels,
+        outputs = Dense(units=number_of_outputs,
                         activation=layer_activation)(outputs)
         resnet_model = Model(inputs=input_image, outputs=outputs)
 
