@@ -102,7 +102,7 @@ def create_unet_model_2d(input_image_size,
         specific configuration add-ons/tweaks:
             * "attentionGating" -- attention-unet variant in https://pubmed.ncbi.nlm.nih.gov/33288961/
             * "nnUnetActivationStyle" -- U-net activation explained in https://pubmed.ncbi.nlm.nih.gov/33288961/
-            * "initialConvolutionalKernelSize[X]" -- Set the first two convolutional layer kernel sizes to X.
+            * "initialConvolutionKernelSize[X]" -- Set the first two convolutional layer kernel sizes to X.
 
     Returns
     -------
@@ -117,7 +117,7 @@ def create_unet_model_2d(input_image_size,
 
     def nn_unet_activation(x):
         x = InstanceNormalization()(x)
-        x = LeakyReLU(alpha=0.01)(x)
+        x = LeakyReLU(negative_slope=0.01)(x)
         return x
 
     def attention_gate_2d(x, g, inter_shape):
@@ -184,7 +184,7 @@ def create_unet_model_2d(input_image_size,
                           padding='same',
                           kernel_regularizer=regularizers.l2(weight_decay))(pool)
 
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             conv = nn_unet_activation(conv)
         else:
             conv = ReLU()(conv)
@@ -201,7 +201,7 @@ def create_unet_model_2d(input_image_size,
                           kernel_size=convolution_kernel_size,
                           padding='same')(conv)
 
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             conv = nn_unet_activation(conv)
         else:
             conv = ReLU()(conv)
@@ -229,11 +229,11 @@ def create_unet_model_2d(input_image_size,
                                  kernel_size=deconvolution_kernel_size,
                                  padding='same',
                                  kernel_regularizer=regularizers.l2(weight_decay))(outputs)
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             deconv = nn_unet_activation(deconv)
         deconv = UpSampling2D(size=pool_size)(deconv)
 
-        if add_attention_gating == True:
+        if add_attention_gating:
             outputs = attention_gate_2d(deconv,
               encoding_convolution_layers[number_of_layers-i-1],
               number_of_filters[number_of_layers-i-1] // 4)
@@ -245,7 +245,7 @@ def create_unet_model_2d(input_image_size,
                          kernel_size=convolution_kernel_size,
                          padding='same',
                          kernel_regularizer=regularizers.l2(weight_decay))(outputs)
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             outputs = nn_unet_activation(outputs)
         else:
             outputs = ReLU()(outputs)
@@ -258,7 +258,7 @@ def create_unet_model_2d(input_image_size,
                          padding='same',
                          kernel_regularizer=regularizers.l2(weight_decay))(outputs)
 
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             outputs = nn_unet_activation(outputs)
         else:
             outputs = ReLU()(outputs)
@@ -394,7 +394,7 @@ def create_unet_model_3d(input_image_size,
 
     def nn_unet_activation(x):
         x = InstanceNormalization()(x)
-        x = LeakyReLU(alpha=0.01)(x)
+        x = LeakyReLU(negative_slope=0.01)(x)
         return x
 
     def attention_gate_3d(x, g, inter_shape):
@@ -461,7 +461,7 @@ def create_unet_model_3d(input_image_size,
                           padding='same',
                           kernel_regularizer=regularizers.l2(weight_decay))(pool)
 
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             conv = nn_unet_activation(conv)
         else:
             conv = ReLU()(conv)
@@ -478,7 +478,7 @@ def create_unet_model_3d(input_image_size,
                           kernel_size=convolution_kernel_size,
                           padding='same')(conv)
 
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             conv = nn_unet_activation(conv)
         else:
             conv = ReLU()(conv)
@@ -506,11 +506,11 @@ def create_unet_model_3d(input_image_size,
                                  kernel_size=deconvolution_kernel_size,
                                  padding='same',
                                  kernel_regularizer=regularizers.l2(weight_decay))(outputs)
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             deconv = nn_unet_activation(deconv)
         deconv = UpSampling3D(size=pool_size)(deconv)
 
-        if add_attention_gating == True:
+        if add_attention_gating:
             outputs = attention_gate_3d(deconv,
               encoding_convolution_layers[number_of_layers-i-1],
               number_of_filters[number_of_layers-i-1] // 4)
@@ -522,7 +522,7 @@ def create_unet_model_3d(input_image_size,
                          kernel_size=convolution_kernel_size,
                          padding='same',
                          kernel_regularizer=regularizers.l2(weight_decay))(outputs)
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             outputs = nn_unet_activation(outputs)
         else:
             outputs = ReLU()(outputs)
@@ -535,7 +535,7 @@ def create_unet_model_3d(input_image_size,
                          padding='same',
                          kernel_regularizer=regularizers.l2(weight_decay))(outputs)
 
-        if nn_unet_activation_style == True:
+        if nn_unet_activation_style:
             outputs = nn_unet_activation(outputs)
         else:
             outputs = ReLU()(outputs)
