@@ -8,7 +8,6 @@ def brain_age(t1,
               do_preprocessing=True,
               number_of_simulations=0,
               sd_affine=0.01,
-              antsxnet_cache_directory=None,
               verbose=False):
 
     """
@@ -43,11 +42,6 @@ def brain_age(t1,
     sd_affine : float
         Define the standard deviation of the affine transformation parameter.
 
-    antsxnet_cache_directory : string
-        Destination directory for storing the downloaded template and model weights.
-        Since these can be resused, if is None, these data will be downloaded to a
-        ~/.keras/ANTsXNet/.
-
     verbose : boolean
         Print progress to the screen.
 
@@ -65,14 +59,10 @@ def brain_age(t1,
 
     from ..utilities import preprocess_brain_image
     from ..utilities import get_pretrained_network
-    from ..utilities import randomly_transform_image_data
 
     if t1.dimension != 3:
         raise ValueError( "Image dimension must be 3." )
 
-    if antsxnet_cache_directory == None:
-        antsxnet_cache_directory = "ANTsXNet"
-
     ################################
     #
     # Preprocess images
@@ -88,7 +78,6 @@ def brain_age(t1,
             template_transform_type="antsRegistrationSyNQuickRepro[a]",
             do_bias_correction=True,
             do_denoising=True,
-            antsxnet_cache_directory=antsxnet_cache_directory,
             verbose=verbose)
         t1_preprocessed = t1_preprocessing["preprocessed_image"] * t1_preprocessing['brain_mask']
 
@@ -100,7 +89,7 @@ def brain_age(t1,
     #
     ################################
 
-    model_weights_file_name = get_pretrained_network("brainAgeDeepBrainNet", antsxnet_cache_directory=antsxnet_cache_directory)
+    model_weights_file_name = get_pretrained_network("brainAgeDeepBrainNet")
     model = keras.models.load_model(model_weights_file_name)
 
     # The paper only specifies that 80 slices are used for prediction.  I just picked
@@ -117,7 +106,7 @@ def brain_age(t1,
     input_image_list.append(input_image)
 
     if number_of_simulations > 0:
-        data_augmentation = randomly_transform_image_data(
+        data_augmentation = ants.randomly_transform_image_data(
             reference_image=t1_preprocessed,
             input_image_list=input_image_list,
             number_of_simulations=number_of_simulations,
