@@ -5,7 +5,6 @@ import ants
 def claustrum_segmentation(t1,
                            do_preprocessing=True,
                            use_ensemble=True,
-                           antsxnet_cache_directory=None,
                            verbose=False):
 
     """
@@ -31,11 +30,6 @@ def claustrum_segmentation(t1,
     use_ensemble : boolean
         check whether to use all 3 sets of weights.
 
-    antsxnet_cache_directory : string
-        Destination directory for storing the downloaded template and model weights.
-        Since these can be resused, if is None, these data will be downloaded to a
-        ~/.keras/ANTsXNet/.
-
     verbose : boolean
         Print progress to the screen.
 
@@ -50,17 +44,12 @@ def claustrum_segmentation(t1,
     """
 
     from ..architectures import create_sysu_media_unet_model_2d
-    from ..utilities import brain_extraction
     from ..utilities import get_pretrained_network
     from ..utilities import preprocess_brain_image
-    from ..utilities import pad_or_crop_image_to_size
 
     if t1.dimension != 3:
         raise ValueError( "Image dimension must be 3." )
 
-    if antsxnet_cache_directory == None:
-        antsxnet_cache_directory = "ANTsXNet"
-
     image_size = (180, 180)
 
     ################################
@@ -78,7 +67,6 @@ def claustrum_segmentation(t1,
             brain_extraction_modality="t1",
             do_bias_correction=True,
             do_denoising=True,
-            antsxnet_cache_directory=antsxnet_cache_directory,
             verbose=verbose)
         t1_preprocessed = t1_preprocessing["preprocessed_image"]
         brain_mask = t1_preprocessing["brain_mask"]
@@ -124,7 +112,7 @@ def claustrum_segmentation(t1,
 
     unet_axial_models = list()
     for i in range(number_of_models):
-        weights_file_name = get_pretrained_network("claustrum_axial_" + str(i), antsxnet_cache_directory=antsxnet_cache_directory)
+        weights_file_name = get_pretrained_network("claustrum_axial_" + str(i))
         unet_axial_models.append(create_sysu_media_unet_model_2d((*image_size, number_of_channels), anatomy="claustrum"))
         unet_axial_models[i].load_weights(weights_file_name)
 
@@ -133,7 +121,7 @@ def claustrum_segmentation(t1,
 
     unet_coronal_models = list()
     for i in range(number_of_models):
-        weights_file_name = get_pretrained_network("claustrum_coronal_" + str(i), antsxnet_cache_directory=antsxnet_cache_directory)
+        weights_file_name = get_pretrained_network("claustrum_coronal_" + str(i))
         unet_coronal_models.append(create_sysu_media_unet_model_2d((*image_size, number_of_channels), anatomy="claustrum"))
         unet_coronal_models[i].load_weights(weights_file_name)
 
@@ -155,7 +143,7 @@ def claustrum_segmentation(t1,
             print("Extracting slices for dimension ", dimensions_to_predict[d], ".")
 
         for i in range(number_of_slices):
-            t1_slice = pad_or_crop_image_to_size(ants.slice_image(t1_preprocessed_warped, dimensions_to_predict[d], i), image_size)
+            t1_slice = ants.pad_or_crop_image_to_size(ants.slice_image(t1_preprocessed_warped, dimensions_to_predict[d], i), image_size)
             if dimensions_to_predict[d] == 1:
                 batch_coronal_X[i,:,:,0] = np.rot90(t1_slice.numpy(), k=-1)
             else:
@@ -210,7 +198,7 @@ def claustrum_segmentation(t1,
             prediction_per_dimension = prediction_axial[which_batch_slices,:,:,:]
         prediction_array = np.transpose(np.squeeze(prediction_per_dimension), permutations[dimensions_to_predict[d]])
         prediction_image = ants.copy_image_info(t1_preprocessed_warped,
-          pad_or_crop_image_to_size(ants.from_numpy(prediction_array),
+          ants.pad_or_crop_image_to_size(ants.from_numpy(prediction_array),
             t1_preprocessed_warped.shape))
         prediction_image_average = prediction_image_average + (prediction_image - prediction_image_average) / (d + 1)
 
