@@ -8,11 +8,10 @@ from tensorflow.keras import regularizers
 
 def lung_extraction(image,
                     modality="proton",
-                    antsxnet_cache_directory=None,
                     verbose=False):
 
     """
-    Perform proton or ct lung extraction using U-net.
+    Perform lung extraction.
 
     Arguments
     ---------
@@ -20,13 +19,8 @@ def lung_extraction(image,
         input image
 
     modality : string
-        Modality image type.  Options include "ct", "proton", "protonLobes", 
-        "maskLobes", and "ventilation".
-
-    antsxnet_cache_directory : string
-        Destination directory for storing the downloaded template and model weights.
-        Since these can be resused, if is None, these data will be downloaded to a
-        ~/.keras/ANTsXNet/.
+        Modality image type.  Options include "ct", "proton", "protonLobes",
+        "maskLobes", "ventilation", and "xray".
 
     verbose : boolean
         Print progress to the screen.
@@ -44,13 +38,11 @@ def lung_extraction(image,
     from ..architectures import create_unet_model_3d
     from ..utilities import get_pretrained_network
     from ..utilities import get_antsxnet_data
-    from ..utilities import pad_or_crop_image_to_size
 
-    if image.dimension != 3:
+    if image.dimension != 3 and modality != "xray":
         raise ValueError( "Image dimension must be 3." )
-
-    if antsxnet_cache_directory == None:
-        antsxnet_cache_directory = "ANTsXNet"
+    elif image.dimension != 2 and modality == "xray":
+        raise ValueError( "Image dimension must be 2." )
 
     image_mods = [modality]
     channel_size = len(image_mods)
@@ -59,14 +51,12 @@ def lung_extraction(image,
     unet_model = None
 
     if modality == "proton":
-        weights_file_name = get_pretrained_network("protonLungMri",
-            antsxnet_cache_directory=antsxnet_cache_directory)
+        weights_file_name = get_pretrained_network("protonLungMri")
 
         classes = ("background", "left_lung", "right_lung")
         number_of_classification_labels = len(classes)
 
-        reorient_template_file_name_path = get_antsxnet_data("protonLungTemplate",
-            antsxnet_cache_directory=antsxnet_cache_directory)
+        reorient_template_file_name_path = get_antsxnet_data("protonLungTemplate")
         reorient_template = ants.image_read(reorient_template_file_name_path)
 
         resampled_image_size = reorient_template.shape
@@ -77,7 +67,7 @@ def lung_extraction(image,
             convolution_kernel_size=(7, 7, 5), deconvolution_kernel_size=(7, 7, 5))
         unet_model.load_weights(weights_file_name)
 
-        if verbose == True:
+        if verbose:
             print("Lung extraction:  normalizing image to the template.")
 
         center_of_mass_template = ants.get_center_of_mass(reorient_template * 0 + 1)
@@ -103,7 +93,7 @@ def lung_extraction(image,
             ants.from_numpy(np.squeeze(predicted_data[0, :, :, :, i]),
                 origin=origin, spacing=spacing, direction=direction))
 
-        if verbose == True:
+        if verbose:
             print("Lung extraction:  renormalize probability mask to native space.")
 
         for i in range(number_of_classification_labels):
@@ -120,14 +110,12 @@ def lung_extraction(image,
         return(return_dict)
 
     if modality == "protonLobes" or modality == "maskLobes":
-        reorient_template_file_name_path = get_antsxnet_data("protonLungTemplate",
-            antsxnet_cache_directory=antsxnet_cache_directory)
+        reorient_template_file_name_path = get_antsxnet_data("protonLungTemplate")
         reorient_template = ants.image_read(reorient_template_file_name_path)
 
         resampled_image_size = reorient_template.shape
 
-        spatial_priors_file_name_path = get_antsxnet_data("protonLobePriors",
-            antsxnet_cache_directory=antsxnet_cache_directory)
+        spatial_priors_file_name_path = get_antsxnet_data("protonLobePriors")
         spatial_priors = ants.image_read(spatial_priors_file_name_path)
         priors_image_list = ants.ndimage_to_list(spatial_priors)
 
@@ -135,7 +123,7 @@ def lung_extraction(image,
         number_of_classification_labels = 1 + len(priors_image_list)
 
         unet_model = create_unet_model_3d((*resampled_image_size, channel_size),
-            number_of_outputs=number_of_classification_labels, mode="classification", 
+            number_of_outputs=number_of_classification_labels, mode="classification",
             number_of_filters_at_base_layer=16, number_of_layers=4,
             convolution_kernel_size=(3, 3, 3), deconvolution_kernel_size=(2, 2, 2),
             dropout_rate=0.0, weight_decay=0, additional_options=("attentionGating",))
@@ -147,15 +135,13 @@ def lung_extraction(image,
                             activation='sigmoid',
                             kernel_regularizer=regularizers.l2(0.0))(penultimate_layer)
             unet_model = Model(inputs=unet_model.input, outputs=[unet_model.output, outputs2])
-            weights_file_name = get_pretrained_network("protonLobes",
-                antsxnet_cache_directory=antsxnet_cache_directory)
+            weights_file_name = get_pretrained_network("protonLobes")
         else:
-            weights_file_name = get_pretrained_network("maskLobes",
-                antsxnet_cache_directory=antsxnet_cache_directory)
+            weights_file_name = get_pretrained_network("maskLobes")
 
         unet_model.load_weights(weights_file_name)
 
-        if verbose == True:
+        if verbose:
             print("Lung extraction:  normalizing image to the template.")
 
         center_of_mass_template = ants.get_center_of_mass(reorient_template * 0 + 1)
@@ -169,7 +155,7 @@ def lung_extraction(image,
             warped_array = (warped_array - warped_array.mean()) / warped_array.std()
         else:
             warped_array[warped_array != 0] = 1
-       
+
         batchX = np.zeros((1, *warped_array.shape, channel_size))
         batchX[0,:,:,:,0] = warped_array
         for i in range(len(priors_image_list)):
@@ -192,7 +178,7 @@ def lung_extraction(image,
                     ants.from_numpy(np.squeeze(predicted_data[0, :, :, :, i]),
                     origin=origin, spacing=spacing, direction=direction))
 
-        if verbose == True:
+        if verbose:
             print("Lung extraction:  renormalize probability images to native space.")
 
         for i in range(number_of_classification_labels):
@@ -228,7 +214,7 @@ def lung_extraction(image,
         #
         ################################
 
-        if verbose == True:
+        if verbose:
             print("Preprocess CT image.")
 
         def closest_simplified_direction_matrix(direction):
@@ -276,11 +262,10 @@ def lung_extraction(image,
         #
         ################################
 
-        if verbose == True:
+        if verbose:
             print("Build model and load weights.")
 
-        weights_file_name = get_pretrained_network("lungCtWithPriorsSegmentationWeights",
-            antsxnet_cache_directory=antsxnet_cache_directory)
+        weights_file_name = get_pretrained_network("lungCtWithPriorsSegmentationWeights")
 
         classes = ("background", "left lung", "right lung", "airways")
         number_of_classification_labels = len(classes)
@@ -303,7 +288,7 @@ def lung_extraction(image,
         #
         ################################
 
-        if verbose == True:
+        if verbose:
             print("Prediction.")
 
         batchX = np.zeros((1, *reference_image_size, channel_size))
@@ -316,7 +301,7 @@ def lung_extraction(image,
 
         probability_images = list()
         for i in range(number_of_classification_labels):
-            if verbose == True:
+            if verbose:
                 print("Reconstructing image", classes[i])
             probability_image = ants.from_numpy(np.squeeze(predicted_data[:,:,:,:,i]),
                 origin=ct_preprocessed_warped.origin, spacing=ct_preprocessed_warped.spacing,
@@ -345,7 +330,7 @@ def lung_extraction(image,
         #
         ################################
 
-        if verbose == True:
+        if verbose:
             print("Preprocess ventilation image.")
 
         template_size = (256, 256)
@@ -368,11 +353,10 @@ def lung_extraction(image,
             convolution_kernel_size=(3, 3), deconvolution_kernel_size=(2, 2),
             weight_decay=0)
 
-        if verbose == True:
+        if verbose:
             print("Whole lung mask: retrieving model weights.")
 
-        weights_file_name = get_pretrained_network("wholeLungMaskFromVentilation",
-            antsxnet_cache_directory=antsxnet_cache_directory)
+        weights_file_name = get_pretrained_network("wholeLungMaskFromVentilation")
         unet_model.load_weights(weights_file_name)
 
         ################################
@@ -394,11 +378,11 @@ def lung_extraction(image,
         for d in range(len(dimensions_to_predict)):
             number_of_slices = preprocessed_image.shape[dimensions_to_predict[d]]
 
-            if verbose == True:
+            if verbose:
                 print("Extracting slices for dimension ", dimensions_to_predict[d], ".")
 
             for i in range(number_of_slices):
-                ventilation_slice = pad_or_crop_image_to_size(ants.slice_image(preprocessed_image, dimensions_to_predict[d], i), template_size)
+                ventilation_slice = ants.pad_or_crop_image_to_size(ants.slice_image(preprocessed_image, dimensions_to_predict[d], i), template_size)
                 batchX[slice_count,:,:,0] = ventilation_slice.numpy()
                 slice_count += 1
 
@@ -408,7 +392,7 @@ def lung_extraction(image,
         #
         ################################
 
-        if verbose == True:
+        if verbose:
             print("Prediction.")
 
         prediction = unet_model.predict(batchX, verbose=verbose)
@@ -422,13 +406,13 @@ def lung_extraction(image,
 
         current_start_slice = 0
         for d in range(len(dimensions_to_predict)):
-            current_end_slice = current_start_slice + preprocessed_image.shape[dimensions_to_predict[d]] - 1
+            current_end_slice = current_start_slice + preprocessed_image.shape[dimensions_to_predict[d]]
             which_batch_slices = range(current_start_slice, current_end_slice)
 
             prediction_per_dimension = prediction[which_batch_slices,:,:,0]
             prediction_array = np.transpose(np.squeeze(prediction_per_dimension), permutations[dimensions_to_predict[d]])
             prediction_image = ants.copy_image_info(image,
-                pad_or_crop_image_to_size(ants.from_numpy(prediction_array),
+                ants.pad_or_crop_image_to_size(ants.from_numpy(prediction_array),
                 image.shape))
             probability_image = probability_image + (prediction_image - probability_image) / (d + 1)
 
@@ -436,6 +420,61 @@ def lung_extraction(image,
 
         return(probability_image)
 
+    elif modality == "xray":
+
+        weights_file_name = get_pretrained_network("xrayLungExtraction")
+
+        classes = ("background", "left_lung", "right_lung")
+        number_of_classification_labels = len(classes)
+        resampled_image_size = (256, 256)
+        channel_size = 3
+
+        resampled_image = ants.resample_image(image, resampled_image_size, use_voxels=True, interp_type=0)
+        xray_lung_priors = ants.ndimage_to_list(ants.image_read(get_antsxnet_data("xrayLungPriors")))
+
+        unet_model = create_unet_model_2d((*resampled_image_size, channel_size),
+            number_of_outputs=number_of_classification_labels, mode="classification",
+            number_of_filters_at_base_layer=32, number_of_layers=4,
+            convolution_kernel_size=(3, 3), deconvolution_kernel_size=(2, 2),
+            dropout_rate=0.0, weight_decay=0,
+            additional_options=None)
+        unet_model.load_weights(weights_file_name)
+
+        batchX = np.zeros((1, *resampled_image_size, channel_size))
+        resampled_array = resampled_image.numpy()
+        batchX[0,:,:,0] = (resampled_array - resampled_array.min()) / (resampled_array.max() - resampled_array.min())
+        batchX[0,:,:,1] = xray_lung_priors[0].numpy()
+        batchX[0,:,:,2] = xray_lung_priors[1].numpy()
+
+        predicted_data = unet_model.predict(batchX, verbose=int(verbose))
+
+        origin = resampled_image.origin
+        spacing = resampled_image.spacing
+        direction = resampled_image.direction
+
+        probability_images_array = list()
+        for i in range(number_of_classification_labels):
+            probability_images_array.append(
+            ants.from_numpy(np.squeeze(predicted_data[0,:,:,i]),
+                origin=origin, spacing=spacing, direction=direction))
+
+        if verbose:
+            print("Lung extraction:  renormalize probability mask to native space.")
+
+        for i in range(number_of_classification_labels):
+            probability_images_array[i] = ants.resample_image(probability_images_array[i],
+                image.shape, use_voxels=True, interp_type=0)
+            probability_images_array[i] = ants.copy_image_info(image, probability_images_array[i])
+
+        image_matrix = ants.image_list_to_matrix(probability_images_array, image * 0 + 1)
+        segmentation_matrix = np.argmax(image_matrix, axis=0)
+        segmentation_image = ants.matrix_to_images(
+            np.expand_dims(segmentation_matrix, axis=0), image * 0 + 1)[0]
+
+        return_dict = {'segmentation_image' : segmentation_image,
+                       'probability_images' : probability_images_array}
+        return(return_dict)
+
     else:
         return ValueError("Unrecognized modality.")
 
