@@ -13,7 +13,6 @@ def preprocess_brain_image(image,
                            intensity_matching_type=None,
                            reference_image=None,
                            intensity_normalization_type=None,
-                           antsxnet_cache_directory=None,
                            verbose=True):
 
     """
@@ -35,7 +34,7 @@ def preprocess_brain_image(image,
     brain_extraction_modality : string or None
         Perform brain extraction using antspynet tools.  One of "t1", "t1v0",
         "t1nobrainer", "t1combined", "flair", "t2", "bold", "fa", "t1infant",
-        "t2infant", or None.
+        "t2infant", "t1threetissue", or None.
 
     template_transform_type : string
         See details in help for ants.registration.  Typically "Rigid" or
@@ -66,11 +65,6 @@ def preprocess_brain_image(image,
         Either rescale the intensities to [0,1] (i.e., "01") or zero-mean, unit variance
         (i.e., "0mean").  If None normalization is not performed.
 
-    antsxnet_cache_directory : string
-        Destination directory for storing the downloaded template and model weights.
-        Since these can be resused, if is None, these data will be downloaded to a
-        ~/.keras/ANTsXNet/.
-
     verbose : boolean
         Print progress to the screen.
 
@@ -87,13 +81,9 @@ def preprocess_brain_image(image,
     """
 
     from ..utilities import brain_extraction
-    from ..utilities import regression_match_image
     from ..utilities import get_antsxnet_data
 
-    preprocessed_image = ants.image_clone(image)
-
-    if antsxnet_cache_directory == None:
-        antsxnet_cache_directory = "ANTsXNet"
+    preprocessed_image = ants.image_clone(image, pixeltype='float')
 
     # Truncate intensity
     if truncate_intensity is not None:
@@ -107,20 +97,24 @@ def preprocess_brain_image(image,
     # Brain extraction
     mask = None
     if brain_extraction_modality is not None:
-        if verbose == True:
+        if verbose:
             print("Preprocessing:  brain extraction.")
 
-        probability_mask = brain_extraction(preprocessed_image, modality=brain_extraction_modality,
-            antsxnet_cache_directory=antsxnet_cache_directory, verbose=verbose)
-        mask = ants.threshold_image(probability_mask, 0.5, 1, 1, 0)
-        mask = ants.morphology(mask,"close",6).iMath_fill_holes()
+        bext = brain_extraction(preprocessed_image, modality=brain_extraction_modality, verbose=verbose)
+        if brain_extraction_modality == "t1threetissue":
+            mask = ants.threshold_image(bext['segmentation_image'], 1, 1, 1, 0)
+        elif brain_extraction_modality == "t1combined":
+            mask = ants.threshold_image(bext, 2, 3, 1, 0)
+        else:
+            mask = ants.threshold_image(bext, 0.5, 1, 1, 0)
+            mask = ants.morphology(mask,"close",6).iMath_fill_holes()
 
     # Template normalization
     transforms = None
     if template_transform_type is not None:
         template_image = None
         if isinstance(template, str):
-            template_file_name_path = get_antsxnet_data(template, antsxnet_cache_directory=antsxnet_cache_directory)
+            template_file_name_path = get_antsxnet_data(template)
             template_image = ants.image_read(template_file_name_path)
         else:
             template_image = template
@@ -132,9 +126,11 @@ def preprocess_brain_image(image,
             transforms = dict(fwdtransforms=registration['fwdtransforms'],
                               invtransforms=registration['invtransforms'])
         else:
-            template_probability_mask = brain_extraction(template_image, modality=brain_extraction_modality, 
-                antsxnet_cache_directory=antsxnet_cache_directory, verbose=verbose)
-            template_mask = ants.threshold_image(template_probability_mask, 0.5, 1, 1, 0)
+            template_bext = brain_extraction(template_image, modality=brain_extraction_modality, verbose=verbose)
+            if brain_extraction_modality == "t1threetissue":
+                template_mask = ants.threshold_image(template_bext['segmentation_image'], 1, 1, 1, 0)
+            else:
+                template_mask = ants.threshold_image(template_bext, 0.5, 1, 1, 0)
             template_brain_image = template_mask * template_image
 
             preprocessed_brain_image = preprocessed_image * mask
@@ -145,9 +141,10 @@ def preprocess_brain_image(image,
                               invtransforms=registration['invtransforms'])
 
             preprocessed_image = ants.apply_transforms(fixed = template_image, moving = preprocessed_image,
-                transformlist=registration['fwdtransforms'], interpolator="linear", verbose=verbose)
+                transformlist=registration['fwdtransforms'], interpolator="linear", singleprecision=True, verbose=verbose)
             mask = ants.apply_transforms(fixed = template_image, moving = mask,
-                transformlist=registration['fwdtransforms'], interpolator="genericLabel", verbose=verbose)
+                transformlist=registration['fwdtransforms'], interpolator="genericLabel", singleprecision=True,
+                verbose=verbose)
 
     # Do bias correction
     bias_field = None
@@ -180,7 +177,7 @@ def preprocess_brain_image(image,
             print("Preprocessing:  intensity matching.")
 
         if intensity_matching_type == "regression":
-            preprocessed_image = regression_match_image(preprocessed_image, reference_image)
+            preprocessed_image = ants.regression_match_image(preprocessed_image, reference_image)
         elif intensity_matching_type == "histogram":
             preprocessed_image = ants.histogram_match_image(preprocessed_image, reference_image)
         else:
