@@ -42,7 +42,6 @@ def tid_neural_image_assessment(image,
                                 stride_length=None,
                                 padding_size=0,
                                 dimensions_to_predict=0,
-                                antsxnet_cache_directory=None,
                                 which_model="tidsQualityAssessment",
                                 image_scaling = [255,127.5],
                                 do_patch_scaling=False,
@@ -90,11 +89,6 @@ def tid_neural_image_assessment(image,
         if image dimension is 3, this parameter specifies which dimensions should be used for
         prediction.  If more than one dimension is specified, the results are averaged.
 
-    antsxnet_cache_directory : string
-        Destination directory for storing the downloaded template and model weights.
-        Since these can be resused, if is None, these data will be downloaded to
-        ~/.keras/ANTsXNet/.
-
     which_model : string or tf/keras model
         model type e.g. string tidsQualityAssessment, koniqMS, koniqMS2 or koniqMS3 where
         the former predicts mean opinion score (MOS) and MOS standard deviation and
@@ -129,9 +123,6 @@ def tid_neural_image_assessment(image,
     """
 
     from ..utilities import get_pretrained_network
-    from ..utilities import pad_or_crop_image_to_size
-    from ..utilities import extract_image_patches
-    from ..utilities import reconstruct_image_from_patches
 
     def is_prime(n):
         if n == 2 or n == 3:
@@ -160,15 +151,12 @@ def tid_neural_image_assessment(image,
     if not which_model in valid_models:
         raise ValueError("Please pass valid model")
 
-    if antsxnet_cache_directory == None:
-        antsxnet_cache_directory = "ANTsXNet"
-
     if verbose == True:
         print("Neural QA:  retreiving model and weights.")
 
     is_koniq = "koniq" in which_model
     if which_model != "user_defined":
-        model_and_weights_file_name = get_pretrained_network(which_model, antsxnet_cache_directory=antsxnet_cache_directory)
+        model_and_weights_file_name = get_pretrained_network(which_model)
         tid_model = tf.keras.models.load_model(model_and_weights_file_name, compile=False)
 
     padding_size_vector = padding_size
@@ -181,7 +169,7 @@ def tid_neural_image_assessment(image,
         dimensions_to_predict = (dimensions_to_predict,)
 
     padded_image_size = image.shape + padding_size_vector
-    padded_image = pad_or_crop_image_to_size(image, padded_image_size)
+    padded_image = ants.pad_or_crop_image_to_size(image, padded_image_size)
 
     number_of_channels = 3
 
@@ -309,10 +297,10 @@ def tid_neural_image_assessment(image,
                     raise ValueError("dimensions_to_predict elements should be 1, 2, and/or 3 for 3-D image.")
 
             if mask is None:
-                patches = extract_image_patches(evaluation_image, patch_size=patch_size_vector,
+                patches = ants.extract_image_patches(evaluation_image, patch_size=patch_size_vector,
                     stride_length=stride_length_vector, return_as_array=False)
             else:
-                patches = extract_image_patches(evaluation_image, patch_size=patch_size_vector,
+                patches = ants.extract_image_patches(evaluation_image, patch_size=patch_size_vector,
                     max_number_of_patches=int((mask==1).sum()),
                     return_as_array=False, mask_image=mask,  randomize=False )
 
@@ -371,15 +359,15 @@ def tid_neural_image_assessment(image,
                 print("reconstruct")
 
             if mask is None:
-                mos += pad_or_crop_image_to_size(reconstruct_image_from_patches(
+                mos += ants.pad_or_crop_image_to_size(ants.reconstruct_image_from_patches(
                     patches_mos, evaluation_image, stride_length=stride_length_vector), image.shape)
-                mos_standard_deviation += pad_or_crop_image_to_size(reconstruct_image_from_patches(
+                mos_standard_deviation += ants.pad_or_crop_image_to_size(ants.reconstruct_image_from_patches(
                     patches_mos_standard_deviation, evaluation_image,
                     stride_length=stride_length_vector), image.shape)
             else:
-                mos += pad_or_crop_image_to_size(reconstruct_image_from_patches(
+                mos += ants.pad_or_crop_image_to_size(ants.reconstruct_image_from_patches(
                     patches_mos, mask, domain_image_is_mask=True), image.shape)
-                mos_standard_deviation += pad_or_crop_image_to_size(reconstruct_image_from_patches(
+                mos_standard_deviation += ants.pad_or_crop_image_to_size(ants.reconstruct_image_from_patches(
                     patches_mos_standard_deviation, mask,  domain_image_is_mask=True), image.shape)
 
         mos /= len(dimensions_to_predict)
